@@ -1475,78 +1475,124 @@ def config_(var=None, value=None, global_cfg=False, unset=False, list_config=Fal
     else:
         subcommands['config'].error("too few arguments")
 
-def scons_upload(args):
+def _call_scons_target(target, command, extra_args=None):
+    """ Call scons to run specific command """
     if os.path.exists('ucube.py') == True:
-        make_args = ['scons -f ucube.py COMMAND=upload']
+        make_args = ['scons -f ucube.py COMMAND=' + command]
     else:
-        make_args = ['scons -f build/ucube.py COMMAND=upload']
+        make_args = ['scons -f build/ucube.py COMMAND=' + command]
 
     target_find = False
 
-    for arg in args:
-        if '@' in arg and not target_find:
-            targets = arg.split('@')
-            if len(targets) < 2:
-                error('Must special app and board when build aos')
+    if '@' in target and not target_find:
+        targets = target.split('@')
+        if len(targets) < 2:
+            error('Must special app and board when build aos')
 
-            app = 'APPLICATION='+targets[0]
-            board = 'BOARD=' + targets[1]
-            make_args.append(app)
-            make_args.append(board)
+        app = 'APPLICATION='+targets[0]
+        board = 'BOARD=' + targets[1]
+        make_args.append(app)
+        make_args.append(board)
 
-            if len(targets) == 3:
-                build_type = 'TYPE=' + targets[2]
-                make_args.append(build_type)
+        if len(targets) == 3:
+            build_type = 'TYPE=' + targets[2]
+            make_args.append(build_type)
 
-            target_find = True
-        #else:
-        #    ret = make_args.append(arg)
+        target_find = True
+
+    if extra_args:
+        make_args += extra_args
 
     ret = popen(' '.join(make_args), shell=True, cwd=os.getcwd())
-#    ret = subprocess.call(make_args, stdout=sys.stdout, stderr=sys.stderr)
+
     return ret
 
-def _run_upload(target, aos_path):
-    from .constant import ver
-    log('aos-cube version: %s\n' %ver)
-    # Get the make arguments
-    args = sys.argv[2:]
-    ret = scons_upload(args)
-    return ret
-
-
-
 # upload command
 @subcommand('upload',
             dict(name='target', help='aos target, e.g. helloworld@starterkit'),
+            dict(name=['-w', '--work-path'], dest='work_path',
+                 help='Alternative work path if aos_sdk_path is unavailable'),
+            dict(name=['-b', '--binaries-dir'], dest='bin_dir',
+                 help='Dir to store upload binaries'),
             help='Upload aos image',
             description="Upload aos image to target platform.")
 
-def upload(target):
+def upload(target, work_path=None, bin_dir=None):
     from .constant import ver
     log('aos-cube version: %s\n' %ver)
+    log("[INFO]: Target: %s\n" % target)
 
-    log("[INFO]:target: %s\n" % target)
-
-    if os.path.isdir('./kernel/rhino') == False:
-        log("[INFO]:Not in aos_sdk_path, curr_path:'%s'\n" % os.getcwd())
-        aos_path = Global().get_cfg(AOS_SDK_PATH)
-        if aos_path == None:
-            error("[ERRO]:Not in aos_sdk_path, aos_sdk unavailable as well. Please run 'aos new $prj_name'!")
+    if work_path:
+        if os.path.isdir(work_path):
+            aos_path = work_path
         else:
-            log("[INFO]:Config Loading OK, use '%s' as sdk path\n" % aos_path)
+            error("Can't find dir %s" % work_path)
     else:
-        aos_path = os.getcwd()
-        log("[INFO]:Currently in aos_sdk_path: '%s'\n" % os.getcwd())
+        if os.path.isdir('./kernel/rhino') == False:
+            log("[INFO]: Not in aos_sdk_path, curr_path:'%s'\n" % os.getcwd())
+            aos_path = Global().get_cfg(AOS_SDK_PATH)
+            if aos_path == None:
+                error("[ERRO]: Not in aos_sdk_path, aos_sdk unavailable as well. Please run 'aos new $prj_name'!")
+            else:
+                log("[INFO]: Config Loading OK, use '%s' as sdk path\n" % aos_path)
+        else:
+            aos_path = os.getcwd()
+            log("[INFO]: Currently in aos_sdk_path: '%s'\n" % os.getcwd())
 
     if '@' not in target or len(target.split('@')) != 2:
-        error('target invalid')
+        error('Target invalid')
         return;
 
-    _run_upload(target, aos_path)
+    extra_args = []
+    extra_args += ['WORKPATH=' + aos_path]
 
+    if bin_dir and not os.path.isdir(bin_dir):
+        error("Can't find dir %s" % bin_dir)
 
+    extra_args = []
+    if work_path:
+        extra_args += ['WORKPATH=' + work_path]
+    if bin_dir:
+        extra_args += ['BINDIR=' + bin_dir]
 
+    _call_scons_target(target, 'upload', extra_args)
+
+# debug command
+@subcommand('debug',
+            dict(name='target', help='aos target, e.g. helloworld@starterkit'),
+            dict(name=['-w', '--work-path'], dest='work_path',
+                 help='Alternative work path if aos_sdk_path is unavailable'),
+            dict(name=['-b', '--binaries-dir'], dest='bin_dir',
+                 help='Dir to store debug binaries'),
+            dict(name=['-c', '--client'], dest='start_client', action='store_true',
+                 help='Start gdb client'),
+            help='Debug aos image',
+            description="Initialize debug env for aos image.")
+
+def debug(target, work_path=None, bin_dir=None, start_client=False):
+    from .constant import ver
+    log('aos-cube version: %s\n' %ver)
+    log("[INFO]: Target: %s\n" % target)
+
+    if work_path and not os.path.isdir(work_path):
+        error("Can't find dir %s" % work_path)
+
+    if bin_dir and not os.path.isdir(bin_dir):
+        error("Can't find dir %s" % bin_dir)
+
+    extra_args = []
+    if work_path and os.path.isdir(work_path):
+        extra_args += ['WORKPATH=' + work_path]
+
+    if bin_dir and os.path.isdir(bin_dir):
+        extra_args += ['BINDIR=' + bin_dir]
+
+    if start_client:
+        extra_args += ['STARTCLIENT=True']
+
+    _call_scons_target(target, 'debug', extra_args)
+
+# monitor command
 @subcommand('monitor',
             dict(name='port', help='Choose serial port'),
             dict(name='baud', help='Select baudrate'),
