@@ -351,14 +351,18 @@ class Repo(object):
         elif m_repo_url:
             repo.name = os.path.basename(path or m_repo_url.group(2)[:-4])
             if repo.name == OS_NAME:
-                repo.path = os.path.abspath(os.path.join(Global().get_path(), repo.name))
+                if path:
+                    repo.path = os.path.abspath(path)
+                else:
+                    repo.path = os.path.abspath(os.path.join(Global().get_path(), repo.name))
+
                 Global().set_cfg(AOS_SDK_PATH, repo.path.replace(os.path.sep, '/'))
             else:
                 pd = Program(os.getcwd())
                 repo.path = os.path.abspath(path or os.path.join(pd.get_cfg(REMOTE_PATH), repo.name))
             repo.url = formaturl(m_repo_url.group(1))
             repo.rev = m_repo_url.group(3)
-            if repo.rev and repo.rev != 'master' and not re.match(r'^([a-fA-F0-9]{6,40})$', repo.rev):
+            if repo.rev and repo.rev != 'master' and not re.match(r'^([a-fA-F0-9]{6,40})$', repo.rev) and not re.match(r'^rel_\d+\.\d+\.\d+$', repo.rev):
                 error('Invalid revision (%s)' % repo.rev, -1)
         else:
             error('Invalid repository (%s)' % url.strip(), -1)
